<?php

namespace Larayellow\Yellowpage\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Litepie\Repository\Filter\RequestFilter;
use Larayellow\Yellowpage\Forms\Yellowpage as YellowpageForm;
use Larayellow\Yellowpage\Http\Requests\YellowpageRequest;
use Larayellow\Yellowpage\Interfaces\YellowpageRepositoryInterface;
use Larayellow\Yellowpage\Repositories\Eloquent\Filters\YellowpageResourceFilter;
use Larayellow\Yellowpage\Repositories\Eloquent\Presenters\YellowpageListPresenter;

/**
 * Resource controller class for yellowpage.
 */
class YellowpageResourceController extends BaseController
{

    /**
     * Initialize yellowpage resource controller.
     *
     *
     * @return null
     */
    public function __construct(YellowpageRepositoryInterface $yellowpage)
    {
        parent::__construct();
        $this->form = YellowpageForm::setAttributes()->toArray();
        $this->modules = $this->modules(config('larayellow.yellowpage.modules'), 'yellowpage', guard_url('yellowpage'));
        $this->repository = $yellowpage;
    }

    /**
     * Display a list of yellowpage.
     *
     * @return Response
     */
    public function index(YellowpageRequest $request)
    {

        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(YellowpageResourceFilter::class)
            ->setPresenter(YellowpageListPresenter::class)
            ->simplePaginate($pageLimit)
            // ->withQueryString()
            ->toArray();

        extract($data);
        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('yellowpage::yellowpage.names'))
            ->view('yellowpage::yellowpage.index')
            ->data(compact('data', 'meta', 'links', 'modules', 'form'))
            ->output();
    }

    /**
     * Display yellowpage.
     *
     * @param Request $request
     * @param Model   $yellowpage
     *
     * @return Response
     */
    public function show(YellowpageRequest $request, YellowpageRepositoryInterface $repository)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = $repository->toArray();
        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('yellowpage::yellowpage.name'))
            ->data(compact('data', 'form', 'modules', 'form'))
            ->view('yellowpage::yellowpage.show')
            ->output();
    }

    /**
     * Show the form for creating a new yellowpage.
     *
     * @param Request $request
     *x
     * @return Response
     */
    public function create(YellowpageRequest $request, YellowpageRepositoryInterface $repository)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = $repository->toArray();
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('yellowpage::yellowpage.name'))
            ->view('yellowpage::yellowpage.create')
            ->data(compact('data', 'form', 'modules'))
            ->output();
    }

    /**
     * Create new yellowpage.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(YellowpageRequest $request, YellowpageRepositoryInterface $repository)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $attributes['user_type'] = user_type();
            $repository->create($attributes);
            $data = $repository->toArray();

            return $this->response->message(trans('messages.success.created', ['Module' => trans('yellowpage::yellowpage.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('yellowpage/yellowpage/' . $data['id']))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/yellowpage/yellowpage'))
                ->redirect();
        }

    }

    /**
     * Show yellowpage for editing.
     *
     * @param Request $request
     * @param Model   $yellowpage
     *
     * @return Response
     */
    public function edit(YellowpageRequest $request, YellowpageRepositoryInterface $repository)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = $repository->toArray();

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('yellowpage::yellowpage.name'))
            ->view('yellowpage::yellowpage.edit')
            ->data(compact('data', 'form', 'modules'))
            ->output();
    }

    /**
     * Update the yellowpage.
     *
     * @param Request $request
     * @param Model   $yellowpage
     *
     * @return Response
     */
    public function update(YellowpageRequest $request, YellowpageRepositoryInterface $repository)
    {
        try {
            $attributes = $request->all();
            $repository->update($attributes);
            $data = $repository->toArray();

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('yellowpage::yellowpage.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('yellowpage/yellowpage/' . $data['id']))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('yellowpage/yellowpage/' .  $repository->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the yellowpage.
     *
     * @param Model   $yellowpage
     *
     * @return Response
     */
    public function destroy(YellowpageRequest $request, YellowpageRepositoryInterface $repository)
    {
        try {
            $repository->delete();
            $data = $repository->toArray();

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('yellowpage::yellowpage.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('yellowpage/yellowpage/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('yellowpage/yellowpage/' .  $repository->getRouteKey()))
                ->redirect();
        }

    }
}
